@@ -376,8 +376,11 @@ const EXTENSION_TYPES: Map<&'static str, FileType> = phf_map! {
     "rq"         => FileType::Source, // SPARQL (query language)
     "sass"       => FileType::Source, // Sass
     "scala"      => FileType::Source, // Scala
+    "scm"        => FileType::Source, // Scheme
     "scss"       => FileType::Source, // Sass
+    "sld"        => FileType::Source, // Scheme Library Definition
     "sql"        => FileType::Source, // SQL
+    "ss"         => FileType::Source, // Scheme Source
     "swift"      => FileType::Source, // Swift
     "tcl"        => FileType::Source, // TCL
     "tex"        => FileType::Source, // LaTeX
